#!/bin/bash

echo "*************************************"
echo "BOUSI-PROLOG v1.4 installation script"
echo "*************************************"

# Checks if root is going to install Bousi-Prolog and
# sets the default installation directory 
if [ $UID -eq 0 ]; then
	echo
	echo "You are logged in as root."
	echo -n "Do you want to install Bousi-Prolog for all users (U) or for root only (R)? "
	REPEAT=1
	while [ $REPEAT -eq 1 ]; do
		read -n 1 -s OPTION
		if [ "$OPTION" = "R" ] || [ "$OPTION" = "r" ]; then
			# Default directory is root home
			INSTALLDIR=$HOME/bousi-prolog
			ALLUSERS=0
			REPEAT=0
		elif [ "$OPTION" = "U" ] || [ "$OPTION" = "u" ]; then
			# Default directory is public /usr/local
			INSTALLDIR=/usr/local/bousi-prolog
			ALLUSERS=1
			REPEAT=0
		fi
	done
	echo
else
	# Default directory is user home
	INSTALLDIR=$HOME/bousi-prolog
	ALLUSERS=0
fi

# Asks for the installation directory
REPEAT=1
while [ $REPEAT -eq 1 ]; do
	echo
	if [ $ALLUSERS -eq 1 ]; then
		echo "Bousi-Prolog will be installed for all users at $INSTALLDIR."
	else
		echo "Bousi-Prolog will be installed at $INSTALLDIR."
	fi
	echo -n "Press 'c' to change installation directory or any other key to continue. "
	read -n 1 -s OPTION
	echo
	if [ "$OPTION" = "c" ] || [ "$OPTION" = "C" ]; then
		echo -n "Enter the installation path: "
		read INSTALLDIR
	else
		REPEAT=0
	fi
done

# Copies program files
echo
echo "Copying files..."
mkdir -p $INSTALLDIR
cp bousi $INSTALLDIR
cp closure.so $INSTALLDIR
cp uninstaller.sh $INSTALLDIR

# Makes additional changes to the system
if [ $ALLUSERS -eq 1 ]; then
	# Creates a script to launch Bousi-Prolog in /usr/bin so any user can
	# start the program typing "bousi" in the shell
	echo
	echo "Creating a script to launch Bousi-Prolog in /usr/bin..."
	echo "#!/bin/bash" > /usr/bin/bousi
	echo "BPL_INSDIR=$INSTALLDIR" >> /usr/bin/bousi
	echo "export BPL_INSDIR" >> /usr/bin/bousi
	echo "$INSTALLDIR/bousi" >> /usr/bin/bousi
	chmod a+x /usr/bin/bousi
else
	echo
	echo "Adding Bousi-Prolog directory to the PATH..."
	# Checks if Bousi-Prolog was previously installed
	# (".bplrc" should be then launched inside ".bashrc")
	cat $HOME/.bashrc | grep -x ". \$HOME/.bplrc" > /dev/null
	if [ $? -eq 1 ]; then
		# Modifies ".bashrc" to call ".bplrc" when launching a new shell
		echo >> $HOME/.bashrc
		echo "# Bousi-Prolog initialization" >> $HOME/.bashrc
		echo ". \$HOME/.bplrc" >> $HOME/.bashrc
	fi
	# Creates the ".bplrc" file that sets some needed environment variables
	echo "# Bousi-Prolog home directory" > $HOME/.bplrc
	echo "BPL_INSDIR=$INSTALLDIR" >> $HOME/.bplrc
	echo "export BPL_INSDIR" >> $HOME/.bplrc
	echo "# Adds the previous directory to the PATH" >> $HOME/.bplrc
	echo "PATH=\$PATH:\$BPL_INSDIR" >> $HOME/.bplrc
	echo "export PATH" >> $HOME/.bplrc
	# Updates the environment variables for this shell
	BPL_INSDIR=$INSTALLDIR
	PATH=$PATH:$INSTALLDIR
	export BPL_INSDIR
	export PATH
fi

# Shows how to start Bousi-Prolog
echo
echo "Bousi-Prolog has been installed in your system."
echo "Enter \"bousi\" to start Bousi-Prolog."

# Change to the installation directory
if [ $ALLUSERS -ne 1 ]; then
	cd $INSTALLDIR
fi

